==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Šajā serverī koplietošana starp serveriem nav ieslēgta",
    "The mountpoint name contains invalid characters." : "Montēšanas punkta nosaukums satur nederīgus simbolus.",
    "Invalid or untrusted SSL certificate" : "Nepareizs vai neuzticams SSL sertifikāts",
    "Could not authenticate to remote share, password might be wrong" : "Nesanāca autentificēties pie attālinātās koplietotnes, parole varētu būt nepareiza",
    "Storage not valid" : "Glabātuve nav derīga",
    "Couldn't add remote share" : "Nevarēja pievienot attālināto koplietotni",
    "Shared with you" : "Koplietots ar tevi",
    "Shared with others" : "Koplietots ar citiem",
    "Shared by link" : "Koplietots ar saiti",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Faili un mapes, ko citi koplietos ar tevi, tiks rādīti šeit",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Faili un mapes, ko koplietosi ar citiem, tiks rādīti šeit",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Faili un mapes, ko koplietosit ar saitēm, tiks rādīti šeit",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vai vēlaties pievienot attālināto koplietotni {name} no {owner}@{remote}?",
    "Remote share" : "Attālinātā koplietotne",
    "Remote share password" : "Attālinātās koplietotnes parole",
    "Cancel" : "Atcelt",
    "Add remote share" : "Pievienot attālināto koplietotni",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nav atrasta neviena ownCloud (7. vai augstāka) instalācija {remote}",
    "Invalid ownCloud url" : "Nederīga ownCloud saite",
    "Shared by" : "Dalījās",
    "Sharing" : "Dalīšanās",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> fails vai mape",
    "A file or folder was shared from <strong>another server</strong>" : "Fails vai mape tika koplietota no <strong>cita servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publiski koplietots fails vai mape tika <strong>lejupielādēts</strong>",
    "You received a new remote share from %s" : "Saņēmāt jaunu attālinātu koplietotni no %s",
    "%1$s accepted remote share %2$s" : "%1$s apstiprināja attālināto koplietotni %2$s",
    "%1$s declined remote share %2$s" : "%1$s noraidīja attālināto koplietotni %2$s",
    "%1$s unshared %2$s from you" : "%1$s atslēdza koplietošanu %2$s ar tevi",
    "Public shared folder %1$s was downloaded" : "Publiski koplietota mape %1$s tika lejupielādēta",
    "Public shared file %1$s was downloaded" : "Publiski koplietots fails %1$s tika lejupielādēts",
    "You shared %1$s with %2$s" : "Tu koplietoji %1$s ar %2$s",
    "You shared %1$s with group %2$s" : "Tu koplietoji %1$s ar grupu %2$s",
    "You shared %1$s via link" : "Tu koplietoji %1$s , izmantojot saiti",
    "%2$s shared %1$s with you" : "%2$s koplietoja %1$s ar tevi",
    "Shares" : "Koplietotie",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Password" : "Parole",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Add to your ownCloud" : "Pievienot savam ownCloud",
    "Download" : "Lejupielādēt",
    "Download %s" : "Lejupielādēt %s",
    "Direct link" : "Tiešā saite",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Open documentation" : "Atvērt dokumentāciju",
    "Allow users on this server to send shares to other servers" : "Atļaut šī servera lietotājiem sūtīt koplietotnes uz citiem serveriem",
    "Allow users on this server to receive shares from other servers" : "Atļaut šī servera lietotājiem saņem koplietotnes no citiem serveriem",
    "Public shared file %1$s was downloaded" : "Publiski koplietots fails %1$s tika lejupielādēts",
    "Public shared folder %1$s was downloaded" : "Publiski koplietota mape %1$s tika lejupielādēta"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Šajā serverī koplietošana starp serveriem nav ieslēgta",
    "The mountpoint name contains invalid characters." : "Montēšanas punkta nosaukums satur nederīgus simbolus.",
    "Invalid or untrusted SSL certificate" : "Nepareizs vai neuzticams SSL sertifikāts",
    "Could not authenticate to remote share, password might be wrong" : "Nesanāca autentificēties pie attālinātās koplietotnes, parole varētu būt nepareiza",
    "Storage not valid" : "Glabātuve nav derīga",
    "Couldn't add remote share" : "Nevarēja pievienot attālināto koplietotni",
    "Shared with you" : "Koplietots ar tevi",
    "Shared with others" : "Koplietots ar citiem",
    "Shared by link" : "Koplietots ar saiti",
    "Uploading..." : "Augšupielādē...",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Faili un mapes, ko citi koplietos ar tevi, tiks rādīti šeit",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Faili un mapes, ko koplietosi ar citiem, tiks rādīti šeit",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Faili un mapes, ko koplietosit ar saitēm, tiks rādīti šeit",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vai vēlaties pievienot attālināto koplietotni {name} no {owner}@{remote}?",
    "Remote share" : "Attālinātā koplietotne",
    "Remote share password" : "Attālinātās koplietotnes parole",
    "Cancel" : "Atcelt",
    "Add remote share" : "Pievienot attālināto koplietotni",
    "You can upload into this folder" : "Jūs variet augšuplādēt šajā mapē",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nav atrasta neviena ownCloud (7. vai augstāka) instalācija {remote}",
    "Invalid ownCloud url" : "Nederīga ownCloud saite",
    "Share" : "Dalīties",
    "Shared by" : "Dalījās",
    "Sharing" : "Dalīšanās",
    "Share API is disabled" : "Koplietošanas API ir atslēgta",
    "Wrong share ID, share doesn't exist" : "Nepareizs koplietošanas ID, koplietotne neeksistē",
    "Could not delete share" : "Neizdevās dzēst koplietotni",
    "Please specify a file or folder path" : "Lūdzu norādiet datnes vai mapes ceļu",
    "Wrong path, file/folder doesn't exist" : "Nepareizs ceļš, datne/mape neeksistē",
    "Please specify a valid user" : "Lūdzu norādiet derīgu lietotāju",
    "Group sharing is disabled by the administrator" : "Administrators grupas koplietošanu ir atslēdzis",
    "Please specify a valid group" : "Lūdzu norādiet derīgu grupu",
    "Public link sharing is disabled by the administrator" : "Administrators publisku saites koplietošanu ir atslēdzis",
    "Public upload disabled by the administrator" : "Administrators publisku augšupielādi ir atslēdzis",
    "Public upload is only possible for publicly shared folders" : "Publiska augšupielāde iespējama tikai publiski koplietotām mapēm",
    "Invalid date, date format must be YYYY-MM-DD" : "Nepareizs datums, datumam jābūt YYYY-MM-DD formātā",
    "Unknown share type" : "Nezināms koplietošanas tips",
    "Could not lock path" : "Nevarēja bloķēt ceļu",
    "Can't change permissions for public share links" : "Publiskai koplietošanas saitei nevar mainīt tiesības",
    "Cannot increase permissions" : "Nevar palielināt tiesības",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> fails vai mape",
    "A file or folder was shared from <strong>another server</strong>" : "Fails vai mape tika koplietota no <strong>cita servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publiski koplietots fails vai mape tika <strong>lejupielādēts</strong>",
    "You received a new remote share %2$s from %1$s" : "Jūs saņēmāt jaunu attālinātu koplietotni %2$s no %1$s",
    "You received a new remote share from %s" : "Saņēmāt jaunu attālinātu koplietotni no %s",
    "%1$s accepted remote share %2$s" : "%1$s apstiprināja attālināto koplietotni %2$s",
    "%1$s declined remote share %2$s" : "%1$s noraidīja attālināto koplietotni %2$s",
    "%1$s unshared %2$s from you" : "%1$s atslēdza koplietošanu %2$s ar tevi",
    "Public shared folder %1$s was downloaded" : "Publiski koplietota mape %1$s tika lejupielādēta",
    "Public shared file %1$s was downloaded" : "Publiski koplietots fails %1$s tika lejupielādēts",
    "You shared %1$s with %2$s" : "Tu koplietoji %1$s ar %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s koplietots %1$s ar %3$s",
    "You removed the share of %2$s for %1$s" : "Tu noņēmi koplietošanu no %2$s priekš %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s noņēma koplietošanu no %3$s priekš %1$s",
    "You shared %1$s with group %2$s" : "Tu koplietoji %1$s ar grupu %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s koplietots %1$s ar grupu %3$s",
    "You removed the share of group %2$s for %1$s" : "Tu noņēmi koplietošanu no grupas %2$s priekš %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s noņēma koplietošanu no gruapas %3$s priekš %1$s",
    "You shared %1$s via link" : "Tu koplietoji %1$s , izmantojot saiti",
    "%2$s shared %1$s with you" : "%2$s koplietoja %1$s ar tevi",
    "Shares" : "Koplietotie",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Password" : "Parole",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Expiration date" : "Termiņa datums",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Add to your ownCloud" : "Pievienot savam ownCloud",
    "Download" : "Lejupielādēt",
    "Download %s" : "Lejupielādēt %s",
    "Direct link" : "Tiešā saite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
